@@ -1,6 +1,7 @@
 package new
 
 import (
+	"context"
 	"errors"
 	"fmt"
 
@@ -18,23 +19,23 @@ import (
 	userv1typedclient "github.com/openshift/client-go/user/clientset/versioned/typed/user/v1"
 )
 
-const NewGroupRecommendedName = "new"
-
 var (
 	newLong = templates.LongDesc(`
 		Create a new group.
 
-		This command will create a new group with an optional list of users.`)
+		This command will create a new group with an optional list of users.
+	`)
 
 	newExample = templates.Examples(`
 		# Add a group with no users
-	  %[1]s my-group
+		oc adm groups new my-group
 
-	  # Add a group with two users
-	  %[1]s my-group user1 user2
+		# Add a group with two users
+		oc adm groups new my-group user1 user2
 
-	  # Add a group with one user and shorter output
-	  %[1]s my-group user1 -o name`)
+		# Add a group with one user and shorter output
+		oc adm groups new my-group user1 -o name
+	`)
 )
 
 type NewGroupOptions struct {
@@ -46,7 +47,7 @@ type NewGroupOptions struct {
 	Group string
 	Users []string
 
-	DryRun bool
+	DryRunStrategy kcmdutil.DryRunStrategy
 
 	genericclioptions.IOStreams
 }
@@ -58,13 +59,13 @@ func NewNewGroupOptions(streams genericclioptions.IOStreams) *NewGroupOptions {
 	}
 }
 
-func NewCmdNewGroup(name, fullName string, f kcmdutil.Factory, streams genericclioptions.IOStreams) *cobra.Command {
+func NewCmdNewGroup(f kcmdutil.Factory, streams genericclioptions.IOStreams) *cobra.Command {
 	o := NewNewGroupOptions(streams)
 	cmd := &cobra.Command{
-		Use:     name + " GROUP [USER ...]",
+		Use:     "new GROUP [USER ...]",
 		Short:   "Create a new group",
 		Long:    newLong,
-		Example: fmt.Sprintf(newExample, fullName),
+		Example: newExample,
 		Run: func(cmd *cobra.Command, args []string) {
 			kcmdutil.CheckErr(o.Complete(f, cmd, args))
 			kcmdutil.CheckErr(o.Validate())
@@ -96,10 +97,12 @@ func (o *NewGroupOptions) Complete(f kcmdutil.Factory, cmd *cobra.Command, args
 		return err
 	}
 
-	o.DryRun = kcmdutil.GetDryRunFlag(cmd)
-	if o.DryRun {
-		o.PrintFlags.Complete("%s (dry run)")
+	o.DryRunStrategy, err = kcmdutil.GetDryRunStrategy(cmd)
+	if err != nil {
+		return err
 	}
+
+	kcmdutil.PrintFlagsWithDryRunStrategy(o.PrintFlags, o.DryRunStrategy)
 	o.Printer, err = o.PrintFlags.ToPrinter()
 	if err != nil {
 		return err
@@ -135,9 +138,9 @@ func (o *NewGroupOptions) Run() error {
 		group.Users = append(group.Users, user)
 	}
 
-	if !o.DryRun {
+	if o.DryRunStrategy != kcmdutil.DryRunClient {
 		var err error
-		group, err = o.GroupClient.Groups().Create(group)
+		group, err = o.GroupClient.Groups().Create(context.TODO(), group, metav1.CreateOptions{})
 		if err != nil {
 			return err
 		}
