@@ -20,7 +20,7 @@ import (
 	digest "github.com/opencontainers/go-digest"
 
 	"k8s.io/cli-runtime/pkg/genericclioptions"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 	kcmdutil "k8s.io/kubectl/pkg/cmd/util"
 	"k8s.io/kubectl/pkg/util/templates"
 
@@ -56,30 +56,35 @@ var (
 		  [~<prefix>] - select the layer with the matching digest prefix or return an error
 
 		Negative indices are counted from the end of the list, e.g. [-1] selects the last
-		layer.`)
+		layer.
+		`)
 
 	example = templates.Examples(`
-# Extract the busybox image into the current directory
-%[1]s docker.io/library/busybox:latest
+		# Extract the busybox image into the current directory
+		oc image extract docker.io/library/busybox:latest
 
-# Extract the busybox image to a temp directory (must exist)
-%[1]s docker.io/library/busybox:latest --path /:/tmp/busybox
+		# Extract the busybox image into the current directory for linux/s390x platform
+		# Note: Wildcard filter is not supported with extract. Pass a single os/arch to extract.
+		oc image extract docker.io/library/busybox:latest --filter-by-os=linux/s390x
 
-# Extract a single file from the image into the current directory
-%[1]s docker.io/library/centos:7 --path /bin/bash:.
+		# Extract the busybox image to a temp directory (must exist)
+		oc image extract docker.io/library/busybox:latest --path /:/tmp/busybox
 
-# Extract all .repo files from the image's /etc/yum.repos.d/ folder.
-%[1]s docker.io/library/centos:7 --path /etc/yum.repos.d/*.repo:.
+		# Extract a single file from the image into the current directory
+		oc image extract docker.io/library/centos:7 --path /bin/bash:.
 
-# Extract the last layer in the image
-%[1]s docker.io/library/centos:7[-1]
+		# Extract all .repo files from the image's /etc/yum.repos.d/ folder.
+		oc image extract docker.io/library/centos:7 --path /etc/yum.repos.d/*.repo:.
 
-# Extract the first three layers of the image
-%[1]s docker.io/library/centos:7[:3]
+		# Extract the last layer in the image
+		oc image extract docker.io/library/centos:7[-1]
 
-# Extract the last three layers of the image
-%[1]s docker.io/library/centos:7[-3:]
-`)
+		# Extract the first three layers of the image
+		oc image extract docker.io/library/centos:7[:3]
+
+		# Extract the last three layers of the image
+		oc image extract docker.io/library/centos:7[-3:]
+	`)
 )
 
 type LayerInfo struct {
@@ -92,7 +97,7 @@ type LayerInfo struct {
 // an error, or false to stop processing.
 type TarEntryFunc func(*tar.Header, LayerInfo, io.Reader) (cont bool, err error)
 
-type Options struct {
+type ExtractOptions struct {
 	Mappings []Mapping
 
 	Files []string
@@ -124,8 +129,8 @@ type Options struct {
 	AllLayers bool
 }
 
-func NewOptions(streams genericclioptions.IOStreams) *Options {
-	return &Options{
+func NewExtractOptions(streams genericclioptions.IOStreams) *ExtractOptions {
+	return &ExtractOptions{
 		Paths: []string{},
 
 		IOStreams:       streams,
@@ -134,14 +139,14 @@ func NewOptions(streams genericclioptions.IOStreams) *Options {
 }
 
 // New creates a new command
-func New(name string, streams genericclioptions.IOStreams) *cobra.Command {
-	o := NewOptions(streams)
+func NewExtract(streams genericclioptions.IOStreams) *cobra.Command {
+	o := NewExtractOptions(streams)
 
 	cmd := &cobra.Command{
 		Use:     "extract",
 		Short:   "Copy files from an image to the filesystem",
 		Long:    desc,
-		Example: fmt.Sprintf(example, name+" extract"),
+		Example: example,
 		Run: func(c *cobra.Command, args []string) {
 			kcmdutil.CheckErr(o.Complete(c, args))
 			kcmdutil.CheckErr(o.Validate())
@@ -217,30 +222,39 @@ func parseMappings(images, paths, files []string, requireEmpty bool) ([]Mapping,
 			if len(mapping.From) > 0 {
 				mapping.From = strings.TrimPrefix(mapping.From, "/")
 			}
-			if len(mapping.To) > 0 {
-				fi, err := os.Stat(mapping.To)
-				if os.IsNotExist(err) {
-					return nil, fmt.Errorf("destination path does not exist: %s", mapping.To)
-				}
+
+			toPath := mapping.To
+			if len(toPath) == 0 {
+				toPath = "."
+			}
+			toPath, err := filepath.Abs(toPath)
+			if err != nil {
+				return nil, fmt.Errorf("cannot make path %q absolute: %v", mapping.To, err)
+			}
+			mapping.To = toPath
+
+			fi, err := os.Stat(mapping.To)
+			if os.IsNotExist(err) {
+				return nil, fmt.Errorf("destination path does not exist: %s", mapping.To)
+			}
+			if err != nil {
+				return nil, fmt.Errorf("invalid argument: %s", err)
+			}
+			if !fi.IsDir() {
+				return nil, fmt.Errorf("invalid argument: %s is not a directory", arg)
+			}
+			if requireEmpty {
+				f, err := os.Open(mapping.To)
 				if err != nil {
-					return nil, fmt.Errorf("invalid argument: %s", err)
+					return nil, fmt.Errorf("unable to check directory: %v", err)
 				}
-				if !fi.IsDir() {
-					return nil, fmt.Errorf("invalid argument: %s is not a directory", arg)
+				names, err := f.Readdirnames(1)
+				f.Close()
+				if err != nil && err != io.EOF {
+					return nil, fmt.Errorf("could not check for empty directory: %v", err)
 				}
-				if requireEmpty {
-					f, err := os.Open(mapping.To)
-					if err != nil {
-						return nil, fmt.Errorf("unable to check directory: %v", err)
-					}
-					names, err := f.Readdirnames(1)
-					f.Close()
-					if err != nil && err != io.EOF {
-						return nil, fmt.Errorf("could not check for empty directory: %v", err)
-					}
-					if len(names) > 0 {
-						return nil, fmt.Errorf("directory %s must be empty, pass --confirm to overwrite contents of directory", mapping.To)
-					}
+				if len(names) > 0 {
+					return nil, fmt.Errorf("directory %s must be empty, pass --confirm to overwrite contents of directory", mapping.To)
 				}
 			}
 			mappings = append(mappings, mapping)
@@ -276,7 +290,7 @@ func parseMappings(images, paths, files []string, requireEmpty bool) ([]Mapping,
 	return mappings, nil
 }
 
-func (o *Options) Complete(cmd *cobra.Command, args []string) error {
+func (o *ExtractOptions) Complete(cmd *cobra.Command, args []string) error {
 	if err := o.FilterOptions.Complete(cmd.Flags()); err != nil {
 		return err
 	}
@@ -297,14 +311,14 @@ func (o *Options) Complete(cmd *cobra.Command, args []string) error {
 	return nil
 }
 
-func (o *Options) Validate() error {
+func (o *ExtractOptions) Validate() error {
 	if len(o.Mappings) == 0 {
 		return fmt.Errorf("you must specify one or more paths or files")
 	}
 	return o.FilterOptions.Validate()
 }
 
-func (o *Options) Run() error {
+func (o *ExtractOptions) Run() error {
 	ctx := context.Background()
 	fromContext, err := o.SecurityOptions.Context()
 	if err != nil {
@@ -332,21 +346,11 @@ func (o *Options) Run() error {
 				srcManifest, location, err := imagemanifest.FirstManifest(ctx, from.Ref, repo, o.FilterOptions.Include)
 				if err != nil {
 					if imagemanifest.IsImageForbidden(err) {
-						var msg string
-						if len(o.Mappings) == 1 {
-							msg = "image does not exist or you don't have permission to access the repository"
-						} else {
-							msg = fmt.Sprintf("image %q does not exist or you don't have permission to access the repository", from)
-						}
+						msg := fmt.Sprintf("image %q does not exist or you don't have permission to access the repository", from)
 						return imagemanifest.NewImageForbidden(msg, err)
 					}
 					if imagemanifest.IsImageNotFound(err) {
-						var msg string
-						if len(o.Mappings) == 1 {
-							msg = "image does not exist"
-						} else {
-							msg = fmt.Sprintf("image %q does not exist", from)
-						}
+						msg := fmt.Sprintf("image %q not found: %s", from, err.Error())
 						return imagemanifest.NewImageNotFound(msg, err)
 					}
 					return fmt.Errorf("unable to read image %s: %v", from, err)
